#ifndef NT2_INCLUDE_FUNCTIONS_ISEMPTY_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ISEMPTY_HPP_INCLUDED

#include <nt2/predicates/include/functions/isempty.hpp>

#endif
